require 'spec_helper'

describe Slipsquare::CLI do
  include_context "spec"

  before :each do
    File.open("foo.txt", 'w') {|f| f.write("Laugh and grow fat...") }
  end

  after :each do
    File.delete("foo.txt") if File.exist?("foo.txt")
  end

  describe "upload-chunked" do

    it "uploads a larger file and gives progress" do

      stub_request(:put, "https://api-content.dropbox.com/1/chunked_upload?offset=0").
         with(:body => "Laugh and grow fat...",
              :headers => {'Accept'=>'*/*', 'Authorization'=>/OAuth oauth_body_hash="\S+", oauth_consumer_key="#{app_key}", oauth_nonce="\S+", oauth_signature="\S+", oauth_signature_method="HMAC-SHA1", oauth_timestamp="\S+", oauth_token="#{app_token}", oauth_version="1.0"/, 'Content-Length'=>'21', 'Content-Type'=>'application/octet-stream', 'User-Agent'=>'OAuth gem v0.4.7'}).
         to_return(:status => 200, :body => fixture('chunked_upload'))

      stub_request(:post, "https://api-content.dropbox.com/1/commit_chunked_upload/dropbox/foo.txt?upload_id=v0k84B0AT9fYkfMUp0sBTA").
         with(:headers => {'Accept'=>'*/*', 'Authorization'=>/OAuth oauth_body_hash="\S+", oauth_consumer_key="#{app_key}", oauth_nonce="\S+", oauth_signature="\S+", oauth_signature_method="HMAC-SHA1", oauth_timestamp="\S+", oauth_token="#{app_token}", oauth_version="1.0"/, 'Content-Length'=>'0', 'Content-Type'=>'application/octet-stream', 'User-Agent'=>'OAuth gem v0.4.7'}).
         to_return(:status => 200, :body => fixture('commit_chunked_upload'), :headers => {})

      @cli.chunked_upload('foo.txt')
      expect($stdout.string).to eq <<-eos
Starting chunked upload
Total Size: 21 bytes
Time: 00:00:00 <==========================================> 100% Upload progress
File uploaded successfully!
      eos
    end

  end

end

