require 'spec_helper'

describe Slipsquare::CLI do
  include_context "spec"

  after :each do
    File.delete("otacon.txt") if File.exist?("otacon.txt")
  end

  describe "download" do

    it "downloads a simple text file" do

      stub_request(:get, "https://api-content.dropbox.com/1/files/dropbox/otacon.txt?").
         with(:headers => {'Accept'=>'*/*', 'Authorization'=>/OAuth oauth_consumer_key="#{app_key}", oauth_nonce="\S+", oauth_signature="\S+", oauth_signature_method="HMAC-SHA1", oauth_timestamp="\S+", oauth_token="#{app_token}", oauth_version="1.0"/, 'User-Agent'=>'OAuth gem v0.4.7'}).
         to_return(:status => 200, :body => "Do you think love can bloom even on a battlefield?")

      @cli.download('otacon.txt')
      expect($stdout.string).to eq <<-eos
Download file...
File 'otacon.txt' downloaded successfully!
      eos

      File.read("otacon.txt").should eql "Do you think love can bloom even on a battlefield?"
    end

    it "outputs a message if file not found" do

      stub_request(:get, "https://api-content.dropbox.com/1/files/dropbox/ghost.txt?").
         with(:headers => {'Accept'=>'*/*', 'Authorization'=>/OAuth oauth_consumer_key="#{app_key}", oauth_nonce="\S+", oauth_signature="\S+", oauth_signature_method="HMAC-SHA1", oauth_timestamp="\S+", oauth_token="#{app_token}", oauth_version="1.0"/, 'User-Agent'=>'OAuth gem v0.4.7'}).
         to_return(:status => 404)

      expect { @cli.download('ghost.txt') }.to raise_error(SystemExit)
      expect($stdout.string).to eq <<-eos
Download file...
File Not Found! Could not download
      eos
    end

  end

end

