require 'spec_helper'

describe Slipsquare::CLI do
  include_context "spec"

  describe "mkdir" do
    it "creates the folder" do
      stub_request(:post, "https://api.dropbox.com/1/fileops/create_folder").
      with(
        :body => {"path"=>"new_folder", "root"=>"dropbox"},
        :headers => {'Accept'=>'*/*', 'Authorization'=> /OAuth oauth_consumer_key="#{app_key}", oauth_nonce="\S+", oauth_signature="\S+", oauth_signature_method="HMAC-SHA1", oauth_timestamp="\S+", oauth_token="#{app_token}", oauth_version="1.0"/, 'Content-Length'=>'0', 'Content-Type'=>'application/x-www-form-urlencoded', 'User-Agent'=>'OAuth gem v0.4.7'}).
      to_return(:status => 200, :body => fixture("mkdir_success"))
      @cli.mkdir('new_folder')
      expect($stdout.string).to eq <<-eos
Creating directory on Dropbox...
Directory `new_folder` created successfully
      eos
    end

    it "creates the folder within a folder" do
      stub_request(:post, "https://api.dropbox.com/1/fileops/create_folder").
      with(
        :body => {"path"=>"/qux/foo/bar", "root"=>"dropbox"},
        :headers => {'Accept'=>'*/*', 'Authorization'=> /OAuth oauth_consumer_key="#{app_key}", oauth_nonce="\S+", oauth_signature="\S+", oauth_signature_method="HMAC-SHA1", oauth_timestamp="\S+", oauth_token="#{app_token}", oauth_version="1.0"/, 'Content-Length'=>'0', 'Content-Type'=>'application/x-www-form-urlencoded', 'User-Agent'=>'OAuth gem v0.4.7'}).
      to_return(:status => 200, :body => fixture("mkdir_success"))
      @cli.mkdir('/qux/foo/bar')
      expect($stdout.string).to eq <<-eos
Creating directory on Dropbox...
Directory `/qux/foo/bar` created successfully
      eos
    end

    it "still creates folders with illegal characters" do
      stub_request(:post, "https://api.dropbox.com/1/fileops/create_folder").
      with(
        :body => {"path"=>"new_folder", "root"=>"dropbox"},
        :headers => {'Accept'=>'*/*', 'Authorization'=> /OAuth oauth_consumer_key="#{app_key}", oauth_nonce="\S+", oauth_signature="\S+", oauth_signature_method="HMAC-SHA1", oauth_timestamp="\S+", oauth_token="#{app_token}", oauth_version="1.0"/, 'Content-Length'=>'0', 'Content-Type'=>'application/x-www-form-urlencoded', 'User-Agent'=>'OAuth gem v0.4.7'}).
      to_return(:status => 200, :body => fixture("mkdir_success"))
      @cli.mkdir('\\\:\?\*\new_folder<\>\"\|')
      expect($stdout.string).to eq <<-eos
Creating directory on Dropbox...
Illegal character found! Escaping...
Escaped directory path: new_folder
Directory `new_folder` created successfully
      eos
    end


  end

end

